@@ -32,7 +32,7 @@ class ACOUNTER02(Device):
     def __init__(self, parent = None, address = 0x51, **kwargs):
         Device.__init__(self, parent, address, **kwargs)
 
-    def read_count(self):
+    def read_count(self):			# read atomic counter
         b0 = self.bus.read_byte_data(self.address, 0x00)
         b1 = self.bus.read_byte_data(self.address, 0x01)
         b2 = self.bus.read_byte_data(self.address, 0x02)
@@ -40,10 +40,18 @@ class ACOUNTER02(Device):
         count = bytes(bytearray([b3, b2, b1, b0]))
         return struct.unpack(">L", count)[0]
 
-    def get_freq(self):
+    def get_freq(self):				# get frequency from counter
         count = self.read_count()
         return (count/(10.0 - 100.0e-6))         #convert  ~10s  of pulse counting to  frequency
 
+    def set_GPS(self):				# set GPS mode by GPS configuration sentence
+        self.bus.write_byte_data(self.address, 0x00, 0)
+
+    # write configuration byte to GPS configuration sentence
+    # First byte of configuration sentence is length of sentence.
+    # Maximal length of configuration sentence is 50 bytes.
+    def conf_GPS(self,addr, byte):		
+        self.bus.write_byte_data(self.address, addr, byte)
 
 if __name__ == "__main__":
     while True:
